class HightonConstants:
    # is used for requests
    GET = 'GET'
    POST = 'POST'
    PUT = 'PUT'
    DELETE = 'DELETE'
    HIGHRISE_URL = 'highrisehq.com'

    # Company
    COMPANIES = 'companies'
    COMPANY = 'company'
    COMPANY_NAME = 'company-name'
    COMPANY_ID = 'company-id'

    # Case
    KASES = 'kases'

    # Deal
    DEALS = 'deals'

    TASK = 'task'
    TASKS = 'tasks'

    # Person
    PEOPLE = 'people'
    PERSON = 'person'

    EMAIL = 'email'
    EMAILS = 'emails'

    USER = 'user'
    USERS = 'users'

    GROUP = 'group'
    GROUPS = 'groups'

    NAME = 'name'
    TITLE = 'title'
    FIRST_NAME = 'first-name'
    LAST_NAME = 'last-name'
    CONTACT_DATA = 'contact-data'
    PARENT_ID = 'parent-id'
    EMAIL_ADDRESS = 'email-address'
    EMAIL_ADDRESSES = 'email-addresses'
    TOKEN = 'token'
    DROPBOX = 'dropbox'
    ADMIN = 'admin'

    WEB_ADDRESS = 'web-address'
    WEB_ADDRESSES = 'web-addresses'

    PHONE_NUMBER = 'phone-number'
    PHONE_NUMBERS = 'phone-numbers'

    SUBJECT_DATA = 'subject_data'
    SUBJECT_DATAS = 'subject_datas'

    ADDRESS = 'address'
    ADDRESSES = 'addresses'

    DEAL_CATEGORIES = 'deal_categories'
    DEAL_CATEGORY = 'deal-category'
    TASK_CATEGORIES = 'task_categories'
    TASK_CATEGORY = 'task-category'

    NOTE = 'note'
    NOTES = 'notes'

    TAG = 'tag'
    TAGS = 'tags'

    SUBJECT_ID = 'subject-id'
    SUBJECT_FIELD = 'subject-field'
    SUBJECT_FIELDS = 'subject_fields'
    SUBJECT_FIELD_ID = 'subject_field_id'
    SUBJECT_FIELD_LABEL = 'subject_field_label'

    URL = 'url'
    ZIP = 'zip'
    CITY = 'city'
    STATE = 'state'
    STREET = 'street'
    NUMBER = 'number'
    COUNTRY = 'country'
    LOCATION = 'location'

    ID = 'id'
    BODY = 'body'
    TYPE = 'type'
    VALUE = 'value'
    LABEL = 'label'
    SEARCH = 'search'
    COMMENT = 'comment'
    COMMENTS = 'comments'
    BACKGROUND = 'background'
    RECORDING_ID = 'recording-id'
    FRAME = 'frame'
    ALERT_AT = 'alert-at'
    PUBLIC = 'public'
    RECURRING_PERIOD = 'recurring-period'
    ANCHOR_TYPE = 'anchor-type'
    DONE_AT = 'done-at'

    AUTHOR_ID = 'author-id'
    CLOSED_AT = 'closed-at'
    CREATED_AT = 'created-at'
    UPDATED_AT = 'updated-at'
    VISIBLE_TO = 'visible-to'
    GROUP_ID = 'group-id'
    OWNER_ID = 'owner-id'
    LINKEDIN_URL = 'linkedin-url'
    AVATAR_URL = 'avatar_url'

    ALL = 'all'
    DEAL = 'deal'
    PARTY = 'party'
    PARTIES = 'parties'

    CASE = 'kase'
    CASES = 'kases'

    TWITTER_ACCOUNTS = 'twitter-accounts'
    TWITTER_ACCOUNT = 'twitter-account'

    USERNAME = 'username'
    PROTOCOL = 'protocol'

    COLOR = 'color'

    INSTANT_MESSENGERS = 'instant-messengers'
    INSTANT_MESSENGER = 'instant-messenger'

    ASSOCIATED_PARTIES = 'associated-parties'
    ASSOCIATED_PARTY = 'associated-party'

    ACCOUNT_ID = 'account-id'
    CATEGORY_ID = 'category-id'
    CURRENCY = 'currency'
    DURATION = 'duration'
    PARTY_ID = 'party-id'
    PRICE = 'price'
    PRICE_TYPE = 'price-type'
    RESPONSIBLE_PARTY_ID = 'responsible-party-id'
    STATUS = 'status'
    STATUS_CHANGED_ON = 'status-changed-on'
    CATEGORY = 'category'
    SIZE = 'size'
    DUE_AT = 'due-at'

    ELEMENTS_COUNT = 'elements-count'

    WON = 'won'
    PENDING = 'pending'
    LOST = 'lost'

    COLLECTION_ID = 'collection-id'
    COLLECTION_TYPE = 'collection-type'

    ATTACHMENTS = 'attachments'
    ATTACHMENT = 'attachment'

    SUBJECT_NAME = 'subject-name'
    SUBJECT_TYPE = 'subject-type'
    SUBJECT_TYPES = [COMPANIES, KASES, DEALS, PEOPLE, ]
    CUSTOM_FIELD_TYPES = [PARTY, DEAL, ALL, ]
